import { useRef, forwardRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs/index.js';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { naturalNumber } from './prop-types.js';
import { BASE_CLASS, JUSTIFY_CONTENT, ALIGNMENT, DESIGN } from './settings.js';
import Stepper from './Stepper/Stepper.js';
import { StepsProvider, useStepsContext } from './context/index.js';
import Step from './Step/Step.js';
import { jsx as _jsx } from "react/jsx-runtime";
var MoleculeStepper = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$as = _ref.as,
      as = _ref$as === void 0 ? 'ol' : _ref$as,
      _ref$asSteps = _ref.asSteps,
      asSteps = _ref$asSteps === void 0 ? 'li' : _ref$asSteps,
      children = _ref.children,
      _ref$design = _ref.design,
      design = _ref$design === void 0 ? DESIGN.DEFAULT : _ref$design,
      _ref$alignment = _ref.alignment,
      alignment = _ref$alignment === void 0 ? ALIGNMENT.HORIZONTAL : _ref$alignment,
      _ref$justifyContent = _ref.justifyContent,
      justifyContent = _ref$justifyContent === void 0 ? JUSTIFY_CONTENT.LEGACY : _ref$justifyContent,
      _ref$labels = _ref.labels,
      labels = _ref$labels === void 0 ? [] : _ref$labels,
      steps = _ref.steps,
      step = _ref.step,
      icon = _ref.icon,
      visitedIcon = _ref.visitedIcon,
      currentIcon = _ref.currentIcon,
      _ref$hasConnector = _ref.hasConnector,
      hasConnector = _ref$hasConnector === void 0 ? true : _ref$hasConnector,
      onChange = _ref.onChange;
  var innerRef = useRef();
  var ref = useMergeRefs(innerRef, forwardedRef);
  return /*#__PURE__*/_jsx(Poly, {
    as: as,
    ref: ref,
    role: "list",
    "data-steps": "" + steps,
    className: cx(BASE_CLASS, [BASE_CLASS + "--design-" + design, BASE_CLASS + "--alignment-" + alignment, BASE_CLASS + "--justifyContent-" + justifyContent]),
    children: /*#__PURE__*/_jsx(StepsProvider, {
      design: design,
      alignment: alignment,
      icon: icon,
      visitedIcon: visitedIcon,
      currentIcon: currentIcon,
      justifyContent: justifyContent,
      as: asSteps,
      hasConnector: hasConnector,
      onChange: onChange,
      children: /*#__PURE__*/_jsx(Stepper, {
        steps: steps,
        step: step,
        labels: labels,
        children: children
      })
    })
  });
});
MoleculeStepper.displayName = 'MoleculeStepper';
export default MoleculeStepper;
export { ALIGNMENT as moleculeStepperAlignment, DESIGN as moleculeStepperDesign, JUSTIFY_CONTENT as moleculeStepperJustifyContent, useStepsContext, Step };